@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2022, QIIME 2 development team.
+# Copyright (c) 2016-2023, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -319,7 +319,7 @@ def _manifest_v2_to_v1(fmt, manifest_fmt):
 
 
 def _manifest_to_df(ff, base_dir):
-    manifest = pd.read_csv(str(ff), header=0, comment='#')
+    manifest = pd.read_csv(str(ff), header=0, comment='#', dtype=str)
     manifest.filename = manifest.filename.apply(
         lambda f: os.path.join(base_dir, f))
 
